<h1 align="center">
	<img width="300" src="https://github.com/mindsdb/mindsdb_native/blob/stable/assets/MindsDBColorPurp@3x.png?raw=true" alt="MindsDB">
	<br>

</h1>
<div align="center">
	<a href="https://github.com/mindsdb/mindsdb/actions"><img src="https://github.com/mindsdb/mindsdb/workflows/MindsDB%20workflow/badge.svg" alt="MindsDB workflow"></a>

  <a href="https://www.python.org/downloads/" target="_blank"><img src="https://img.shields.io/badge/python-3.6%20|%203.7|%203.8-brightgreen.svg" alt="Python supported"></a>
   <a href="https://pypi.org/project/MindsDB/" target="_blank"><img src="https://badge.fury.io/py/MindsDB.svg" alt="PyPi Version"></a>
  <a href="https://pypi.org/project/MindsDB/" target="_blank"><img src="https://img.shields.io/pypi/dm/mindsdb" alt="PyPi Downloads"></a>
  <a href="https://community.mindsdb.com/" target="_blank"><img src="https://img.shields.io/discourse/posts?server=https%3A%2F%2Fcommunity.mindsdb.com%2F" alt="MindsDB Community"></a>
  <a href="https://www.mindsdb.com/"><img src="https://img.shields.io/website?url=https%3A%2F%2Fwww.mindsdb.com%2F" alt="MindsDB Website"></a>	
  
  <h3 align="center">
    <a href="https://www.mindsdb.com/">Website</a>
    <span> | </span>
    <a href="https://docs.mindsdb.com/">Docs</a>
    <span> | </span>
    <a href="https://apidocs.mindsdb.com/">API Docs</a>
    <span> | </span>
    <a href="https://community.mindsdb.com/">Community forum</a>
  </h3>
  
</div>

[MindsDB](https://mindsdb.com/) is an open-source AI layer for existing databases that allows you to effortlessly develop, train and deploy state-of-the-art machine learning models using SQL queries. [![Tweet](https://img.shields.io/twitter/url/http/shields.io.svg?style=social)](https://twitter.com/intent/tweet?text=Machine%20Learning%20in%20one%20line%20of%20code%21&url=https://www.mindsdb.com&via=mindsdb&hashtags=ai,ml,machine_learning,neural_networks)

<h2 align="center">
   Predictive AI layer for existing databases
   <br/>
  <img width="1200" src="https://github.com/mindsdb/mindsdb-docs/blob/master/mindsdb-docs/docs/assets/integration-image.png" alt="MindsDB">	

</h2>


## Features

* **AutoML**. With MindsDB built-in Automated Machine Learning you can quickly generate the right machine learning model.
* **AI Tables**. Move your models instantly to production, reduce resources, and overhead costs with AI Tables that deliver the results as database tables.
* **Explainable AI**. Use MindsDB Studio to interpret predictions made by the model. Identify potential data biases, evaluate and visualize model accuracy using the Explainable AI.




## Try it out

* [Getting started](https://docs.mindsdb.com/)
* [Install MindsDB](https://docs.mindsdb.com/Installing/)
	* [Linux](https://docs.mindsdb.com/installation/Linux/)
	* [Windows](https://docs.mindsdb.com/installation/Windows/)
	* [MacOS](https://docs.mindsdb.com/installation/MacOS/)
	* [Docker](https://docs.mindsdb.com/installation/docker/)
	* [From source](https://docs.mindsdb.com/installation/source/)
* [Tutorials](https://docs.mindsdb.com/databases/)
	* [AI Tables in MariaDB](https://docs.mindsdb.com/tutorials/mysql/)
	* [AI Tables in ClickHouse](https://docs.mindsdb.com/tutorials/clickhouse/)
	* [AI Tables in MySQL](https://docs.mindsdb.com/tutorials/mysql/)
	* [AI Tables in PostgreSQL](https://docs.mindsdb.com/tutorials/postgresql/)
	* [AI Tables in Microsoft SQL Server](https://docs.mindsdb.com/tutorials/microsoft-sql-server/)


## Integrations


AI Tables - Get the predictions you need as simple tables in your database.

|  :electric_plug: :books: | :chart_with_upwards_trend: :wrench: | :mag: :bulb: |
|-|-|-|
|  <a href="https://docs.mindsdb.com/datasources/mariadb/" target="_blank"><img src="https://img.shields.io/badge/MariaDB-Connect%20your%20data-%2300b06d?style=for-the-badge&logo=mariadb" alt="Connect MariaDB"></a>   | <a href="https://docs.mindsdb.com/model/mariadb/"><img src="https://img.shields.io/badge/MariaDB-Train%20new%20model-%2300b06d?style=for-the-badge&logo=mariadb" alt="Tranin new model"></a> | <a href="https://docs.mindsdb.com/model/query/mariadb/"><img src="https://img.shields.io/badge/MariaDB-Query%20the%20model-%2300b06d?style=for-the-badge&logo=mariadb" alt="Query the model"></a> 
|   <a href="https://docs.mindsdb.com/datasources/mysql/" target="_blank"><img src="https://img.shields.io/badge/MySQL-Connect%20your%20data-%2300b06d?style=for-the-badge&logo=mysql" alt="Connect MySQL"></a> | <a href="https://docs.mindsdb.com/model/mysql/"><img src="https://img.shields.io/badge/MySQL-Train%20new%20model-%2300b06d?style=for-the-badge&logo=mysql" alt="Tranin new model"></a> | <a href="https://docs.mindsdb.com/model/query/mysql/"><img src="https://img.shields.io/badge/MySQL-Query%20the%20model-%2300b06d?style=for-the-badge&logo=mysql" alt="Query the model"></a>
|  <a href="https://docs.mindsdb.com/datasources/postgresql/" target="_blank"><img src="https://img.shields.io/badge/PostgreSQL-Connect%20your%20data-%2300b06d?style=for-the-badge&logo=postgresql" alt="Connect PostgreSQL"></a> | <a href="https://docs.mindsdb.com/model/postgresql/"><img src="https://img.shields.io/badge/PostgreSQL-Train%20new%20model-%2300b06d?style=for-the-badge&logo=postgresql" alt="Tranin new model"></a>  | <a href="https://docs.mindsdb.com/model/query/postgresql/"><img src="https://img.shields.io/badge/PostgreSQL-Query%20the%20model-%2300b06d?style=for-the-badge&logo=postgresql" alt="Query the model"></a>
|  <a href="https://docs.mindsdb.com/datasources/clickhouse/" target="_blank"><img src="https://img.shields.io/badge/ClickHouse-Connect%20your%20data-%2300b06d?style=for-the-badge&logo=clickhouse" alt="Connect ClickHouse"></a> | <a href="https://docs.mindsdb.com/model/clickhouse/"><img src="https://img.shields.io/badge/Clickhouse-Train%20new%20model-%2300b06d?style=for-the-badge&logo=clickhouse" alt="Tranin new model"></a> | <a href="https://docs.mindsdb.com/model/query/clickhouse/"><img src="https://img.shields.io/badge/Clickhouse-Query%20the%20model-%2300b06d?style=for-the-badge&logo=database" alt="Query the model"></a>
|  <a href="https://docs.mindsdb.com/datasources/mssql/" target="_blank"><img src="https://img.shields.io/badge/SQL%20Server-Connect%20your%20data-%2300b06d?style=for-the-badge&logo=microsoft" alt="Connect Microsoft SQL Server"></a> | <a href="https://docs.mindsdb.com/model/mssql/"><img src="https://img.shields.io/badge/SQL%20Server-Train%20new%20model-%2300b06d?style=for-the-badge&logo=microsoft" alt="Tranin new model"></a> | <a href="https://docs.mindsdb.com/model/query/mssql/"><img src="https://img.shields.io/badge/SQL%20Server-Query%20the%20model-%2300b06d?style=for-the-badge&logo=microsoft" alt="Query the model"></a>
| <a href="https://docs.mindsdb.com/datasources/snowflake/" target="_blank"><img src="https://img.shields.io/badge/Snowflake-Connect%20your%20data-%2300b06d?style=for-the-badge&logo=snowflake" alt="Connect Snowflake"></a> |  <a href="https://docs.mindsdb.com/model/snowflake/"><img src="https://img.shields.io/badge/Snowflake-Train%20new%20model-%2300b06d?style=for-the-badge&logo=snowflake" alt="Tranin new model"></a> | <a href="https://docs.mindsdb.com/model/query/snowflake/"><img src="https://img.shields.io/badge/Snowflake-Query%20the%20model-%2300b06d?style=for-the-badge&logo=snowflake" alt="Query the model"></a>

| :warning: :construction:  :construction_worker: | :warning: :construction:  :construction_worker: | :warning: :construction:  :construction_worker:|
|-|-|-|
| <a href="https://docs.mindsdb.com/"><img src="https://img.shields.io/badge/MongoDB-Work%20In%20Progress-%2300b06d?style=for-the-badge&logo=mongodb" alt="Connect MongoDB"></a> | <a href="https://docs.mindsdb.com/"><img src="https://img.shields.io/badge/MongoDB-Work%20In%20Progress-%2300b06d?style=for-the-badge&logo=mongodb" alt="Connect MongoDB"></a>  | <a href="https://docs.mindsdb.com/"><img src="https://img.shields.io/badge/MongoDB-Work%20In%20Progress-%2300b06d?style=for-the-badge&logo=mongodb" alt="Connect MongoDB"></a> 

[:question: :wave: Missing integration?](https://github.com/mindsdb/mindsdb/issues/new?assignees=&labels=&template=feature-mindsdb-request.md)

## Contributing

* To contribute to MindsDB, please check out [Contribution docs](https://docs.mindsdb.com/contribute/).
* Welcome to our awesome community, please check out [Community docs](https://docs.mindsdb.com/community/).

### Current contributors

<a href="https://github.com/mindsdb/mindsdb/graphs/contributors">
  <img src="https://contributors-img.web.app/image?repo=mindsdb/mindsdb" />
</a>

Made with [contributors-img](https://contributors-img.web.app).

## Report Issues

Please help us by [reporting any issues](https://github.com/mindsdb/mindsdb/issues/new/choose) you may have while using MindsDB.

## License

* [MindsDB License](https://github.com/mindsdb/mindsdb/blob/master/LICENSE)
